﻿using Android.App;
using Android.Content;
using Android.Content.PM;
using Android.OS;
using Android.Provider;
using Java.IO;
using Java.Lang;
using Syncfusion.SfImageEditor.XForms.Droid;
using System;
using Xamarin.Forms;


[assembly: Dependency(typeof(ImageEditor_GettingStarted.Droid.ImageEditorService))]

namespace ImageEditor_GettingStarted.Droid
{
	[Activity(Label = "ImageEditor_GettingStarted.Droid", Icon = "@drawable/icon", Theme = "@style/MyTheme", MainLauncher = true, ConfigurationChanges = ConfigChanges.ScreenSize | ConfigChanges.Orientation)]
	public class MainActivity : global::Xamarin.Forms.Platform.Android.FormsAppCompatActivity
	{
		protected override void OnCreate(Bundle bundle)
		{
			TabLayoutResource = Resource.Layout.Tabbar;
			ToolbarResource = Resource.Layout.Toolbar;

			base.OnCreate(bundle);

			global::Xamarin.Forms.Forms.Init(this, bundle);
			new SfImageEditorRenderer();

			LoadApplication(new App());
		}
		public event EventHandler<ActivityResultEventArgs> ActivityResult;


		protected override void OnActivityResult(int requestCode, Result resultCode, Intent data)
		{
			if (resultCode == Result.Ok)
			{
				if (ActivityResult != null)
					ActivityResult(this, new ActivityResultEventArgs { Intent = data });

			}
		}
	}




	public class ActivityResultEventArgs : EventArgs
	{

		public Intent Intent
		{
			get;
			set;
		}
	}


		public class ImageEditorService : IImageEditorDependencyService
		{
			private static int SELECT_FROM_GALLERY = 0;
			private static int SELECT_FROM_CAMERA = 1;
			static Intent mainIntent;
			private Android.Net.Uri mImageCaptureUri;
			MainActivity activity;
			bool isCamera = false;

			public void InitializeMediaPicker(ImageEditor_GettingStartedPage editor)
			{
				activity = Xamarin.Forms.Forms.Context as MainActivity;
				activity.ActivityResult += (object sender, ActivityResultEventArgs e) =>
				{
					if (!isCamera)
					{
						var imagePath = GetPathToImage(e.Intent.Data);
						editor.SwitchView(imagePath);
					}
					else
					{
						mainIntent.PutExtra("image-path", mImageCaptureUri.Path);
						mainIntent.PutExtra("scale", true);
						editor.SwitchView(mImageCaptureUri.Path);
					}
				};
				activity.Intent = new Intent();
				activity.Intent.SetType("image/*");
				activity.Intent.SetAction(Intent.ActionGetContent);
				activity.StartActivityForResult(Intent.CreateChooser(activity.Intent, "Select Picture"), SELECT_FROM_GALLERY);

			}

			private void InitializeCamera(ImageEditor_GettingStartedPage editor)
			{
				activity = Xamarin.Forms.Forms.Context as MainActivity;

				activity.ActivityResult += (object sender, ActivityResultEventArgs e) =>
				{
					if (!isCamera)
					{
						var imagePath = GetPathToImage(e.Intent.Data);
						editor.SwitchView(imagePath);
					}
					else
					{
						mainIntent.PutExtra("image-path", mImageCaptureUri.Path);
						mainIntent.PutExtra("scale", true);
						editor.SwitchView(mImageCaptureUri.Path);
					}
				};

				var intent = new Intent(MediaStore.ActionImageCapture);
				mImageCaptureUri = Android.Net.Uri.FromFile(new File(CreateDirectoryForPictures(),
					string.Format("ImageEditor_Photo_{0}.jpg", DateTime.Now.ToString("yyyyMMddHHmmssfff"))));

				intent.PutExtra(MediaStore.ExtraOutput, mImageCaptureUri);

				Intent mediaScanIntent = new Intent(Intent.ActionMediaScannerScanFile);
				mediaScanIntent.SetData(mImageCaptureUri);
				activity.SendBroadcast(mediaScanIntent);

				try
				{
					mainIntent = intent;
					intent.PutExtra("return-data", false);
					activity.StartActivityForResult(mainIntent, SELECT_FROM_CAMERA);
				}
				catch (ActivityNotFoundException e)
				{
					e.PrintStackTrace();
				}
			}

			private string GetPathToImage(Android.Net.Uri uri)
			{
				string imgId = "";
				using (var c1 = activity.ContentResolver.Query(uri, null, null, null, null))
				{
					c1.MoveToFirst();
					string imageId = c1.GetString(0);
					imgId = imageId.Substring(imageId.LastIndexOf(":") + 1);
				}

				string path = null;

				string selection = MediaStore.Images.Media.InterfaceConsts.Id + " =? ";
				using (var cursor = activity.ContentResolver.Query(MediaStore.Images.Media.ExternalContentUri, null, selection, new string[] { imgId }, null))
				{
					if (cursor == null) return path;
					var columnIndex = cursor.GetColumnIndexOrThrow(MediaStore.Images.Media.InterfaceConsts.Data);
					cursor.MoveToFirst();
					path = cursor.GetString(columnIndex);
				}
				return path;
			}

			private File CreateDirectoryForPictures()
			{
				var dir = new File(Android.OS.Environment.GetExternalStoragePublicDirectory(Android.OS.Environment.DirectoryPictures), "ImageEditor");
				if (!dir.Exists())
				{
					dir.Mkdirs();
				}

				return dir;
			}


			void IImageEditorDependencyService.UploadFromCamera(ImageEditor_GettingStartedPage editor)
			{
				isCamera = true;
				InitializeCamera(editor);
			}


			void IImageEditorDependencyService.UploadFromGallery(ImageEditor_GettingStartedPage editor)
			{
				isCamera = false;
				InitializeMediaPicker(editor);

			}
		}
	}

