﻿using Syncfusion.SfImageEditor.XForms;
using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Xamarin.Forms;
using Xamarin.Forms.Xaml;

namespace ImageEditor_GettingStarted
{
	public interface IImageEditorDependencyService
	{
		void UploadFromCamera(ImageEditor_GettingStartedPage editor);

		void UploadFromGallery(ImageEditor_GettingStartedPage editor);
	}

	public interface ISaveImageToFolder
	{
		void Save(Stream stream);
		void Save(string url);
	}
	public partial class ImageEditor_GettingStartedPage : ContentPage
	{
		Grid filePickerGrid;

		public ImageEditor_GettingStartedPage()
		{
			InitializeComponent();
			filePickerGrid = new Grid();
			filePickerGrid.RowDefinitions.Add(new RowDefinition());
			filePickerGrid.RowDefinitions.Add(new RowDefinition());

			Button browsePhoto = new Button();
			browsePhoto.Clicked += BrowsePhoto_Clicked;
			browsePhoto.Text = "Choose from photos";
			browsePhoto.TextColor = Color.Blue;
			browsePhoto.BackgroundColor = Color.Transparent;
			browsePhoto.VerticalOptions = LayoutOptions.End;

			Button takePhoto = new Button();
			takePhoto.Clicked += TakePhoto_Clicked;
			takePhoto.Text = "Take a photo";
			takePhoto.TextColor = Color.Blue;
			takePhoto.BackgroundColor = Color.Transparent;
			takePhoto.VerticalOptions = LayoutOptions.Start;
			Grid.SetRow(takePhoto, 1);

			filePickerGrid.Children.Add(browsePhoto);
			filePickerGrid.Children.Add(takePhoto);

			Content = filePickerGrid;
		}
		public void SwitchView(Stream file)
		{
			Navigation.PushAsync(new NavigationPage(new SfImageEditorPage(file)));
		}

		public void SwitchView(string file)
		{
			Navigation.PopModalAsync();
			Navigation.PushModalAsync(new SfImageEditorPage(file));
		}

		private void TakePhoto_Clicked(object sender, EventArgs e)
		{
			DependencyService.Get<IImageEditorDependencyService>().UploadFromCamera(this);
		}

		private void BrowsePhoto_Clicked(object sender, EventArgs e)
		{
			DependencyService.Get<IImageEditorDependencyService>().UploadFromGallery(this);
		}
	}

	public class SfImageEditorPage : ContentPage
	{
		void Editor_ImageSaved(object sender, ImageSavedEventArgs args)
		{
			DependencyService.Get<ISaveImageToFolder>().Save(args.Location);
		}

		public SfImageEditorPage(string file)
		{
			SfImageEditor editor = new SfImageEditor();
			editor.Source = ImageSource.FromFile(file);
			Content = editor;
			editor.ImageSaved += Editor_ImageSaved;
		}

		public SfImageEditorPage(Stream file)
		{
			SfImageEditor editor = new SfImageEditor();
			editor.Source = ImageSource.FromStream(() => file);
			Content = editor;
			editor.ImageSaved += Editor_ImageSaved;
		}
	}
}
