﻿using System;
using System.Collections.Generic;
using System.Linq;
using Syncfusion.SfImageEditor.XForms.iOS;


using Foundation;
using UIKit;
using UIKit;
using Xamarin.Forms;
using System.IO;
using AssetsLibrary;

[assembly: Dependency(typeof(ImageEditor_GettingStarted.iOS.ImageEditorService))]
[assembly: Dependency(typeof(ImageEditor_GettingStarted.iOS.ImageSaveDependencyService))]
namespace ImageEditor_GettingStarted.iOS
{
	[Register("AppDelegate")]
	public partial class AppDelegate : global::Xamarin.Forms.Platform.iOS.FormsApplicationDelegate
	{
		double statusBarHeight, navBarHeight;

		public override bool FinishedLaunching(UIApplication app, NSDictionary options)
		{
			UIApplication.SharedApplication.StatusBarStyle = UIStatusBarStyle.LightContent;

			statusBarHeight = app.StatusBarFrame.Size.Height;

			global::Xamarin.Forms.Forms.Init();

			LoadApplication(new App());
			SfImageEditorRenderer.Init();

			return base.FinishedLaunching(app, options);
		}
		public override void DidChangeStatusBarOrientation(UIApplication application, UIInterfaceOrientation oldStatusBarOrientation)
		{
			var currentOrientation = UIApplication.SharedApplication.StatusBarOrientation;
			if (currentOrientation == UIInterfaceOrientation.Portrait || currentOrientation == UIInterfaceOrientation.PortraitUpsideDown)
				SetScreenSize(UIScreen.MainScreen.Bounds.Width, UIScreen.MainScreen.Bounds.Height);
			else
				SetScreenSize(UIScreen.MainScreen.Bounds.Height, UIScreen.MainScreen.Bounds.Width);
		}

		public override UIInterfaceOrientationMask GetSupportedInterfaceOrientations(UIApplication application, UIWindow forWindow)
		{
			switch (Device.Idiom)
			{
				case TargetIdiom.Phone:
					return UIInterfaceOrientationMask.Portrait;
				case TargetIdiom.Tablet:
					return UIInterfaceOrientationMask.All;
				default:
					return UIInterfaceOrientationMask.Portrait;
			}
		}

		void SetScreenSize(double width, double height)
		{
			App.StatusBarHeight = statusBarHeight;
			App.NavigationBarHeight = navBarHeight;
			App.ScreenWidth = width;
			App.ScreenHeight = height - statusBarHeight;
		}
	}
	public class ImageEditorService : IImageEditorDependencyService
	{
		UIImagePickerController imagePicker;

		void IImageEditorDependencyService.UploadFromCamera(ImageEditor_GettingStartedPage editor)
		{
			imagePicker = new UIImagePickerController();

			imagePicker.SourceType = UIImagePickerControllerSourceType.Camera;

			imagePicker.MediaTypes = UIImagePickerController.AvailableMediaTypes(UIImagePickerControllerSourceType.Camera);

			imagePicker.FinishedPickingMedia += (object sender, UIImagePickerMediaPickedEventArgs e) =>
		   {
			   imagePicker.DismissModalViewController(true);
			   editor.SwitchView(e.OriginalImage.AsPNG().AsStream());
		   };

			imagePicker.Canceled += (sender, evt) =>
			{
				imagePicker.DismissModalViewController(true);
			};

			var topController = UIApplication.SharedApplication.KeyWindow.RootViewController;
			while (topController.PresentedViewController != null)
			{
				topController = topController.PresentedViewController;
			}
			topController.PresentViewController(imagePicker, true, null);
		}


		void IImageEditorDependencyService.UploadFromGallery(ImageEditor_GettingStartedPage editor)
		{
			imagePicker = new UIImagePickerController();

			imagePicker.SourceType = UIImagePickerControllerSourceType.PhotoLibrary;

			imagePicker.MediaTypes = UIImagePickerController.AvailableMediaTypes(UIImagePickerControllerSourceType.PhotoLibrary);

			imagePicker.FinishedPickingMedia += (object sender, UIImagePickerMediaPickedEventArgs e) =>
			{
				imagePicker.DismissModalViewController(true);
				editor.SwitchView(e.OriginalImage.AsPNG().AsStream());
			};
			imagePicker.Canceled += (sender, evt) =>
			{
				imagePicker.DismissModalViewController(true);
			};

			var topController = UIApplication.SharedApplication.KeyWindow.RootViewController;
			while (topController.PresentedViewController != null)
			{
				topController = topController.PresentedViewController;
			}
			topController.PresentViewController(imagePicker, true, null);
		}
	}

	public class ImageSaveDependencyService : ISaveImageToFolder
	{
		public void Save(Stream stream)
		{
			throw new NotImplementedException();
		}

		void ISaveImageToFolder.Save(string uri)
		{
			ALAssetsLibrary library = new ALAssetsLibrary();
			NSUrl url = new NSUrl(uri);
			library.AssetForUrl(url, (obj) =>
						{
							ALAssetRepresentation rep = obj.DefaultRepresentation;
							var t = UIImage.FromImage(rep.GetFullScreenImage(), rep.Scale, UIImageOrientation.Up);
							Save(t);

						}, (obj) =>
						{



						});

		}

		void Save(UIImage image)
		{
			var documentsDirectory = Environment.GetFolderPath
												(Environment.SpecialFolder.Personal);
			var directoryname = Path.Combine(documentsDirectory, "FolderName");
			Directory.CreateDirectory(directoryname);

			string jpgFilename = System.IO.Path.Combine(directoryname, "newFile");
			image.AsJPEG().Save(jpgFilename, false);
		}

	}
}
